<?php

namespace Drupal\cforge\Plugin\Field\FieldWidget;

use \Drupal\cforge\Plugin\Field\FieldType\ContactMeItem;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Plugin implementation of the 'worth' widget.
 *
 * @FieldWidget(
 *   id = "cf_contactme",
 *   label = @Translation("Contact me"),
 *   field_types = {
 *     "cf_contactme"
 *   },
 *   multiple_values = false
 * )
 */
class ContactMeWidget extends WidgetBase {

  /**
   * Returns the form for a single field widget.
   *
   * @see \Drupal\Core\Field\WidgetInterface
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $w = 0;
    $element = [
      '#title' => $this->t('Contact channels'),
      '#description' => $this->t("Your 'definitive' mail is always visible to Committee members. All other fields are visible to all site members, but not the public."),
      '#type' => 'details',
      '#collapsed' => TRUE,
      '#attributes'=> ['class' => ['channels']],
      '#attached' => ['library' => ['cforge/social_media_icons']],
      'email' => [
        '#type' => 'item',
        '#title' => $this->t('Email (definitive):'),
        '#markup' => $items->getEntity()->getEmail(),// Assumes it is attached to a user entity.
        '#weight' => $w++,
      ],
    ];
    $available_channels = array_filter($this->fieldDefinition->getSetting('channels')??[]);
    foreach (ContactMeItem::CHANNELS as $channel => $info) {
      if (in_array($channel, $available_channels)) {
        $element[$channel] = [
          '#type' => 'textfield',
          '#title' => new TranslatableMarkup($info['title']),
          '#default_value' => $items->{$channel},
          '#weight' => $w++
        ];
        if (!empty($info['example'])) {
          $element[$channel]['#placeholder'] = $info['example'];
        }
        if (!empty($info['regex'])) {
          $element[$channel]['#pattern'] = $info['regex'];
        }
        if (!empty($info['prefix'])) {
          $element[$channel]['#field_prefix'] = $info['prefix'];
        }
      }
    }

    $element['whatsapp']['#type'] = 'select';
    unset($element['whatsapp']['#field_prefix']);
    $element['whatsapp']['#empty_option'] = $this->t('No');
    if (in_array('mob', $available_channels)) {
      $options['mob'] = $this->t('Mobile no.');
    }
    if (in_array('tel', $available_channels)) {
      $options['tel'] = t('Other phone no.');
    }
    if ($options) {
      $element['whatsapp']['#options'] = $options;
      $element['whatsapp']['#states'] = [
        'invisible' => [
          ':input[name="mob"]' => ['!value' => '']
        ]
      ];
    }
    $element['mob']['#required'] = $this->fieldDefinition->isRequired();
    return $element;
  }

}
